ASTRiDE (Automated Streak Detection for Astronomical Images)

ASTRiDE detects streaks in a fits image using a border
of each object and morphological quantities. For details, visit
https://github.com/dwkim78/ASTRiDE
